@@ -21,9 +21,10 @@
  *
  */
 
-int interactive(const gchar *src, const gchar *dst, const gchar *dst_type,
-		gboolean le);
-GIOChannel *gatt_connect(const gchar *src, const gchar *dst,
-			const gchar *dst_type, const gchar *sec_level,
-			int psm, int mtu, BtIOConnect connect_cb);
+int interactive(const char *src, const char *dst, const char *dst_type,
+								int psm);
+GIOChannel *gatt_connect(const char *src, const char *dst,
+			const char *dst_type, const char *sec_level,
+			int psm, int mtu, BtIOConnect connect_cb,
+			GError **gerr);
 size_t gatt_attr_data_from_string(const char *str, uint8_t **data);
