@@ -36,9 +36,24 @@
 
 #include "glib-helper.h"
 
+char *bt_modalias(uint16_t source, uint16_t vendor,
+					uint16_t product, uint16_t version)
+{
+	switch (source) {
+	case 0x0001:
+		return g_strdup_printf("%s:v%04Xp%04Xd%04X",
+					"bluetooth", vendor, product, version);
+	case 0x0002:
+		return g_strdup_printf("%s:v%04Xp%04Xd%04X",
+					"usb", vendor, product, version);
+	}
+
+	return NULL;
+}
+
 char *bt_uuid2string(uuid_t *uuid)
 {
-	gchar *str;
+	char *str;
 	uuid_t uuid128;
 	unsigned int data0;
 	unsigned short data1;
@@ -88,7 +103,6 @@ static struct {
 	const char	*name;
 	uint16_t	class;
 } bt_services[] = {
-	{ "vcp",	VIDEO_CONF_SVCLASS_ID		},
 	{ "pbap",	PBAP_SVCLASS_ID			},
 	{ "sap",	SAP_SVCLASS_ID			},
 	{ "ftp",	OBEX_FILETRANS_SVCLASS_ID	},
